@@ -14,17 +14,18 @@ class AWSClient:
 
   def __init__(self):
     self.s3 = boto3.client("s3")
-    self.kinesis = boto3.client("kinesis", config=Config(region_name = os.environ['AWS_REGION']))
+    self.kinesis_firehose = boto3.client("firehose", config=Config(region_name = os.environ['AWS_REGION']))
     
   # Define new AWS Client if not already instantiated
   def getAWSClient(self):
     return self
 
   # Kinesis
-  def kinesisPutRecord(self, streamName, rawData, partitionKey):
-    response = self.kinesis.put_record(
-      StreamName=streamName,
-      Data=json.dumps(rawData),
-      PartitionKey=partitionKey,
+  def kinesisFirehosePutRecord(self, delivery_stream_name, raw_data):
+    response = self.kinesis_firehose.put_record(
+      DeliveryStreamName=delivery_stream_name,
+      Record = {
+        'Data': json.dumps(raw_data),
+      }
     )
     return response
