@@ -27,7 +27,7 @@ def handler_decorator(handler):
     try:
       return handler(*args, **kwargs)
     except Exception as err:
-      sentry_sdk.capture_exception(str(err))
+      sentry_sdk.capture_exception(err)
       client = sentry_sdk.Hub.current.client
       if client is not None:
         client.flush(timeout=1)
